/****************************************************************************
** Meta object code from reading C++ file 'kcm.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreen-6.6.5/kcm/kcm.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcm.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KCMKScreenE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMKScreen::qt_create_metaobjectdata<qt_meta_tag_ZN10KCMKScreenE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMKScreen",
        "backendReadyChanged",
        "",
        "backendError",
        "changed",
        "screenNormalizedChanged",
        "perOutputScalingChanged",
        "primaryOutputSupportedChanged",
        "outputReplicationSupportedChanged",
        "globalScaleChanged",
        "autoRotationSupportedChanged",
        "orientationSensorAvailableChanged",
        "tabletModeAvailableChanged",
        "invalidConfig",
        "InvalidConfigReason",
        "reason",
        "errorOnSave",
        "errorReason",
        "globalScaleWritten",
        "outputConnect",
        "connected",
        "settingsReverted",
        "showRevertWarning",
        "xwaylandClientsScaleChanged",
        "xwaylandClientsScaleSupportedChanged",
        "tearingSupportedChanged",
        "tearingAllowedChanged",
        "multipleScreensAvailableChanged",
        "identifyOutputs",
        "normalizeScreen",
        "QSize",
        "revertSettings",
        "requestReboot",
        "setStopUpdatesFromBackend",
        "value",
        "updateFromBackend",
        "startHdrCalibrator",
        "outputName",
        "outputModel",
        "QAbstractItemModel*",
        "backendReady",
        "screenNormalized",
        "perOutputScaling",
        "xwaylandClientsScaleSupported",
        "primaryOutputSupported",
        "outputReplicationSupported",
        "tearingSupported",
        "globalScale",
        "tabletModeAvailable",
        "xwaylandClientsScale",
        "tearingAllowed",
        "multipleScreensAvailable",
        "NoEnabledOutputs",
        "ConfigHasGaps"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'backendReadyChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backendError'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenNormalizedChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'perOutputScalingChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'primaryOutputSupportedChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputReplicationSupportedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'globalScaleChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoRotationSupportedChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'orientationSensorAvailableChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabletModeAvailableChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invalidConfig'
        QtMocHelpers::SignalData<void(enum InvalidConfigReason)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'errorOnSave'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Signal 'globalScaleWritten'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'outputConnect'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'settingsReverted'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRevertWarning'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xwaylandClientsScaleChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xwaylandClientsScaleSupportedChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tearingSupportedChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tearingAllowedChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multipleScreensAvailableChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'identifyOutputs'
        QtMocHelpers::MethodData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'normalizeScreen'
        QtMocHelpers::MethodData<QSize() const>(29, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Method 'revertSettings'
        QtMocHelpers::MethodData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'requestReboot'
        QtMocHelpers::MethodData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setStopUpdatesFromBackend'
        QtMocHelpers::MethodData<void(bool)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Method 'updateFromBackend'
        QtMocHelpers::MethodData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'startHdrCalibrator'
        QtMocHelpers::MethodData<void(const QString &)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'outputModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(38, 0x80000000 | 39, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'backendReady'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'screenNormalized'
        QtMocHelpers::PropertyData<bool>(41, QMetaType::Bool, QMC::DefaultPropertyFlags, 3),
        // property 'perOutputScaling'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 4),
        // property 'xwaylandClientsScaleSupported'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 18),
        // property 'primaryOutputSupported'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 5),
        // property 'outputReplicationSupported'
        QtMocHelpers::PropertyData<bool>(45, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'tearingSupported'
        QtMocHelpers::PropertyData<bool>(46, QMetaType::Bool, QMC::DefaultPropertyFlags, 19),
        // property 'globalScale'
        QtMocHelpers::PropertyData<qreal>(47, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'tabletModeAvailable'
        QtMocHelpers::PropertyData<bool>(48, QMetaType::Bool, QMC::DefaultPropertyFlags, 10),
        // property 'xwaylandClientsScale'
        QtMocHelpers::PropertyData<bool>(49, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'tearingAllowed'
        QtMocHelpers::PropertyData<bool>(50, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 20),
        // property 'multipleScreensAvailable'
        QtMocHelpers::PropertyData<bool>(51, QMetaType::Bool, QMC::DefaultPropertyFlags, 21),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'InvalidConfigReason'
        QtMocHelpers::EnumData<enum InvalidConfigReason>(14, 14, QMC::EnumFlags{}).add({
            {   52, InvalidConfigReason::NoEnabledOutputs },
            {   53, InvalidConfigReason::ConfigHasGaps },
        }),
    };
    return QtMocHelpers::metaObjectData<KCMKScreen, qt_meta_tag_ZN10KCMKScreenE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMKScreen::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KCMKScreenE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KCMKScreenE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KCMKScreenE_t>.metaTypes,
    nullptr
} };

void KCMKScreen::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMKScreen *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->backendReadyChanged(); break;
        case 1: _t->backendError(); break;
        case 2: _t->changed(); break;
        case 3: _t->screenNormalizedChanged(); break;
        case 4: _t->perOutputScalingChanged(); break;
        case 5: _t->primaryOutputSupportedChanged(); break;
        case 6: _t->outputReplicationSupportedChanged(); break;
        case 7: _t->globalScaleChanged(); break;
        case 8: _t->autoRotationSupportedChanged(); break;
        case 9: _t->orientationSensorAvailableChanged(); break;
        case 10: _t->tabletModeAvailableChanged(); break;
        case 11: _t->invalidConfig((*reinterpret_cast<std::add_pointer_t<enum InvalidConfigReason>>(_a[1]))); break;
        case 12: _t->errorOnSave((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->globalScaleWritten(); break;
        case 14: _t->outputConnect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->settingsReverted(); break;
        case 16: _t->showRevertWarning(); break;
        case 17: _t->xwaylandClientsScaleChanged(); break;
        case 18: _t->xwaylandClientsScaleSupportedChanged(); break;
        case 19: _t->tearingSupportedChanged(); break;
        case 20: _t->tearingAllowedChanged(); break;
        case 21: _t->multipleScreensAvailableChanged(); break;
        case 22: _t->identifyOutputs(); break;
        case 23: { QSize _r = _t->normalizeScreen();
            if (_a[0]) *reinterpret_cast<QSize*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->revertSettings(); break;
        case 25: _t->requestReboot(); break;
        case 26: _t->setStopUpdatesFromBackend((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->updateFromBackend(); break;
        case 28: _t->startHdrCalibrator((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::backendReadyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::backendError, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::screenNormalizedChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::perOutputScalingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::primaryOutputSupportedChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::outputReplicationSupportedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::globalScaleChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::autoRotationSupportedChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::orientationSensorAvailableChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::tabletModeAvailableChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)(InvalidConfigReason )>(_a, &KCMKScreen::invalidConfig, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)(const QString & )>(_a, &KCMKScreen::errorOnSave, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::globalScaleWritten, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)(bool )>(_a, &KCMKScreen::outputConnect, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::settingsReverted, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::showRevertWarning, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::xwaylandClientsScaleChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::xwaylandClientsScaleSupportedChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::tearingSupportedChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::tearingAllowedChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMKScreen::*)()>(_a, &KCMKScreen::multipleScreensAvailableChanged, 21))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->outputModel(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->backendReady(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->screenNormalized(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->perOutputScaling(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->xwaylandClientsScaleSupported(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->primaryOutputSupported(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->outputReplicationSupported(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->tearingSupported(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->globalScale(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->tabletModeAvailable(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->xwaylandClientsScale(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->allowTearing(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->multipleScreensAvailable(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setGlobalScale(*reinterpret_cast<qreal*>(_v)); break;
        case 10: _t->setXwaylandClientsScale(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setAllowTearing(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCMKScreen::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMKScreen::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KCMKScreenE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMKScreen::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 29;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KCMKScreen::backendReadyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMKScreen::backendError()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KCMKScreen::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KCMKScreen::screenNormalizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KCMKScreen::perOutputScalingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KCMKScreen::primaryOutputSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KCMKScreen::outputReplicationSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KCMKScreen::globalScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KCMKScreen::autoRotationSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KCMKScreen::orientationSensorAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KCMKScreen::tabletModeAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KCMKScreen::invalidConfig(InvalidConfigReason _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void KCMKScreen::errorOnSave(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void KCMKScreen::globalScaleWritten()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KCMKScreen::outputConnect(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}

// SIGNAL 15
void KCMKScreen::settingsReverted()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KCMKScreen::showRevertWarning()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KCMKScreen::xwaylandClientsScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KCMKScreen::xwaylandClientsScaleSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KCMKScreen::tearingSupportedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KCMKScreen::tearingAllowedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KCMKScreen::multipleScreensAvailableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}
QT_WARNING_POP
