/****************************************************************************
** Meta object code from reading C++ file 'hdrcalibrator.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreen-6.6.5/hdrcalibrator/hdrcalibrator.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hdrcalibrator.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13HdrCalibratorE_t {};
} // unnamed namespace

template <> constexpr inline auto HdrCalibrator::qt_create_metaobjectdata<qt_meta_tag_ZN13HdrCalibratorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HdrCalibrator",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "peakBrightnessOverrideChanged",
        "",
        "maxAverageBrightnessOverrideChanged",
        "brightnessChanged",
        "sdrBrightnessChanged",
        "applyConfig",
        "applyConfigForWindowsApps",
        "safeQuit",
        "outputName",
        "peakBrightness",
        "maxAverageBrightness",
        "peakBrightnessOverride",
        "maxAverageBrightnessOverride",
        "brightness",
        "sdrBrightness"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'peakBrightnessOverrideChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxAverageBrightnessOverrideChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'brightnessChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sdrBrightnessChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'applyConfig'
        QtMocHelpers::MethodData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'applyConfigForWindowsApps'
        QtMocHelpers::MethodData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'safeQuit'
        QtMocHelpers::MethodData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'outputName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'peakBrightness'
        QtMocHelpers::PropertyData<qreal>(14, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxAverageBrightness'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'peakBrightnessOverride'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'maxAverageBrightnessOverride'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'brightness'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sdrBrightness'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<HdrCalibrator, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject HdrCalibrator::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13HdrCalibratorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13HdrCalibratorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13HdrCalibratorE_t>.metaTypes,
    nullptr
} };

void HdrCalibrator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HdrCalibrator *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->peakBrightnessOverrideChanged(); break;
        case 1: _t->maxAverageBrightnessOverrideChanged(); break;
        case 2: _t->brightnessChanged(); break;
        case 3: _t->sdrBrightnessChanged(); break;
        case 4: _t->applyConfig(); break;
        case 5: _t->applyConfigForWindowsApps(); break;
        case 6: _t->safeQuit(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (HdrCalibrator::*)()>(_a, &HdrCalibrator::peakBrightnessOverrideChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrCalibrator::*)()>(_a, &HdrCalibrator::maxAverageBrightnessOverrideChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrCalibrator::*)()>(_a, &HdrCalibrator::brightnessChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (HdrCalibrator::*)()>(_a, &HdrCalibrator::sdrBrightnessChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->outputName(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->peakBrightness(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->maxAverageBrightness(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->peakBrightnessOverride(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->maxAverageBrightnessOverride(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->brightness(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->sdrBrightness(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setPeakBrightnessOverride(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setMaxAverageBrightnessOverride(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setBrightness(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setSdrBrightness(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *HdrCalibrator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HdrCalibrator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13HdrCalibratorE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int HdrCalibrator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void HdrCalibrator::peakBrightnessOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void HdrCalibrator::maxAverageBrightnessOverrideChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void HdrCalibrator::brightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void HdrCalibrator::sdrBrightnessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
