/****************************************************************************
** Meta object code from reading C++ file 'hdrhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kscreen-6.6.5/hdrcalibrator/hdrhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'hdrhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9HdrHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto HdrHelper::qt_create_metaobjectdata<qt_meta_tag_ZN9HdrHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HdrHelper",
        "QML.Singleton",
        "true",
        "QML.Element",
        "auto",
        "setHdrParameters",
        "",
        "QQuickWindow*",
        "window",
        "Colorspace",
        "colorspace",
        "uint32_t",
        "referenceLuminance",
        "maximumLuminance",
        "RenderIntent",
        "renderIntent",
        "BT709Linear",
        "BT2020PQ",
        "Perceptual",
        "RelativeColorimetricBPC"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'setHdrParameters'
        QtMocHelpers::MethodData<void(QQuickWindow *, enum Colorspace, uint32_t, uint32_t, enum RenderIntent)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 }, { 0x80000000 | 11, 13 },
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Colorspace'
        QtMocHelpers::EnumData<enum Colorspace>(9, 9, QMC::EnumIsScoped).add({
            {   16, Colorspace::BT709Linear },
            {   17, Colorspace::BT2020PQ },
        }),
        // enum 'RenderIntent'
        QtMocHelpers::EnumData<enum RenderIntent>(14, 14, QMC::EnumIsScoped).add({
            {   18, RenderIntent::Perceptual },
            {   19, RenderIntent::RelativeColorimetricBPC },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<HdrHelper, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject HdrHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9HdrHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9HdrHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9HdrHelperE_t>.metaTypes,
    nullptr
} };

void HdrHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<HdrHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setHdrParameters((*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Colorspace>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<enum RenderIntent>>(_a[5]))); break;
        default: ;
        }
    }
}

const QMetaObject *HdrHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HdrHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9HdrHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int HdrHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN22ColorManagementSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorManagementSurface::qt_create_metaobjectdata<qt_meta_tag_ZN22ColorManagementSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorManagementSurface"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ColorManagementSurface, qt_meta_tag_ZN22ColorManagementSurfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ColorManagementSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ColorManagementSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ColorManagementSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22ColorManagementSurfaceE_t>.metaTypes,
    nullptr
} };

void ColorManagementSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorManagementSurface *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ColorManagementSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorManagementSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22ColorManagementSurfaceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::wp_color_management_surface_v1"))
        return static_cast< QtWayland::wp_color_management_surface_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int ColorManagementSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
